@@ -9,6 +9,13 @@ from tap.directive import Directive
 from tap.i18n import _
 from tap.line import Result
 
+try:
+    import more_itertools  # noqa
+    import yaml  # noqa
+    ENABLE_VERSION_13 = True
+except ImportError:  # pragma: no cover
+    ENABLE_VERSION_13 = False
+
 
 class Tracker(object):
 
@@ -42,6 +49,9 @@ class Tracker(object):
         else:  # pragma: no cover
             self._sanitized_table = str.maketrans(' \\/\n', '----')
 
+        if self.streaming:
+            self._write_tap_version(self.stream)
+
     def _get_outdir(self):
         return self._outdir
 
@@ -118,6 +128,7 @@ class Tracker(object):
             if self.outdir:
                 combined_file = os.path.join(self.outdir, combined_file)
             with open(combined_file, 'w') as out_file:
+                self._write_tap_version(out_file)
                 for test_case in self.combined_test_cases_seen:
                     self.generate_tap_report(
                         test_case, self._test_cases[test_case], out_file)
@@ -126,6 +137,7 @@ class Tracker(object):
         else:
             for test_case, tap_lines in self._test_cases.items():
                 with open(self._get_tap_file_path(test_case), 'w') as out_file:
+                    self._write_tap_version(out_file)
                     self.generate_tap_report(test_case, tap_lines, out_file)
 
     def generate_tap_report(self, test_case, tap_lines, out_file):
@@ -139,6 +151,14 @@ class Tracker(object):
         if not self.combined:
             print('1..{0}'.format(len(tap_lines)), file=out_file)
 
+    def _write_tap_version(self, filename):
+        """Write a Version 13 TAP row
+
+        filename can be a filename or a stream
+        """
+        if ENABLE_VERSION_13:
+            print('TAP version 13', file=filename)
+
     def _write_test_case_header(self, test_case, stream):
         print(_('# TAP results for {test_case}').format(
             test_case=test_case), file=stream)
